==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/nl/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Bevestig bulk verwijdering van assets',
  'bulk_delete_help'	=> 'Bekijk de assets voor bulkverwijdering hieronder. Eenmaal verwijderd, kunnen deze assets worden hersteld, maar ze zullen niet langer geassocieerd worden met gebruikers waaraan ze momenteel zijn toegewezen.',
  'bulk_delete_warn'	=> 'Je staat op het punt om :asset_count assets te verwijderen.',
	'bulk_update'		=> 'Assets in bulk bijwerken',
	'bulk_update_help'	=> 'Met dit formulier kun je meerdere assets tegelijk bijwerken. Vul alleen de velden in die je moet wijzigen. Alle lege velden blijven ongewijzigd. ',
	'bulk_update_warn'	=> 'Je staat op het punt de eigenschappen van :asset_count assets te wijzigen.',
    'checkedout_to'		=> 'Uitgecheckt aan',
    'checkout_date'		=> 'Uitgecheckt datum',
    'checkin_date'		=> 'Ingecheckt datum',
    'checkout_to'		=> 'Uitchecken aan',
    'cost'				=> 'Aankoopprijs',
    'create'			=> 'Asset aanmaken',
    'date'				=> 'Aankoopdatum',
    'depreciation'	    => 'Afschrijving',
    'depreciates_on'	=> 'Afschrijving op',
    'default_location'	=> 'Standaardlocatie',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'Duur EOL',
    'expected_checkin'  => 'Verwachte incheck datum',
    'expires'			=> 'Vervalt op',
    'fully_depreciated'	=> 'Volledig afgeschreven',
    'help_checkout'		=> 'Als je dit asset onmiddellijk wilt toewijzen, selecteer dan "klaar om uit te geven" van de bovenstaande lijst. ',
    'mac_address'		=> 'MAC-adres',
    'manufacturer'		=> 'Fabrikant',
    'model'				=> 'Model',
    'months'			=> 'maanden',
    'name'				=> 'Asset naam',
    'notes'				=> 'Opmerkingen',
    'order'				=> 'Ordernummer',
    'qr'				=> 'QR-code',
    'requestable'		=> 'Gebruikers mogen dit asset aanvragen',
    'select_statustype'	=> 'Selecteer status type',
    'serial'			=> 'Serienummer',
    'status'			=> 'Status',
    'tag'				=> 'Assettag',
    'update'			=> 'Asset update',
    'warranty'			=> 'Garantie',
		'warranty_expires'		=> 'Garantie vervalt',
    'years'				=> 'jaar',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/nl/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Bevestig bulk verwijdering van assets',
  'bulk_delete_help'	=> 'Bekijk de assets voor bulkverwijdering hieronder. Eenmaal verwijderd, kunnen deze assets worden hersteld, maar ze zullen niet langer geassocieerd worden met gebruikers waaraan ze momenteel zijn toegewezen.',
  'bulk_delete_warn'	=> 'Je staat op het punt om :asset_count assets te verwijderen.',
    'bulk_update'		=> 'Assets in bulk bijwerken',
    'bulk_update_help'	=> 'Met dit formulier kun je meerdere assets tegelijk bijwerken. Vul alleen de velden in die je moet wijzigen. Alle lege velden blijven ongewijzigd. ',
    'bulk_update_warn'	=> 'Je staat op het punt de eigenschappen van :asset_count assets te wijzigen.',
    'checkedout_to'		=> 'Uitgecheckt aan',
    'checkout_date'		=> 'Uitgecheckt datum',
    'checkin_date'		=> 'Ingecheckt datum',
    'checkout_to'		=> 'Uitchecken aan',
    'cost'				=> 'Aankoopprijs',
    'create'			=> 'Asset aanmaken',
    'date'				=> 'Aankoopdatum',
    'depreciation'	    => 'Afschrijving',
    'depreciates_on'	=> 'Afschrijving op',
    'default_location'	=> 'Standaardlocatie',
    'eol_date'			=> 'EOL datum',
    'eol_rate'			=> 'Duur EOL',
    'expected_checkin'  => 'Verwachte incheck datum',
    'expires'			=> 'Vervalt op',
    'fully_depreciated'	=> 'Volledig afgeschreven',
    'help_checkout'		=> 'Als je dit asset onmiddellijk wilt toewijzen, selecteer dan "klaar om uit te geven" van de bovenstaande lijst. ',
    'mac_address'		=> 'MAC-adres',
    'manufacturer'		=> 'Fabrikant',
    'model'				=> 'Model',
    'months'			=> 'maanden',
    'name'				=> 'Asset naam',
    'notes'				=> 'Opmerkingen',
    'order'				=> 'Ordernummer',
    'qr'				=> 'QR-code',
    'requestable'		=> 'Gebruikers mogen dit asset aanvragen',
    'select_statustype'	=> 'Selecteer status type',
    'serial'			=> 'Serienummer',
    'status'			=> 'Status',
    'tag'				=> 'Assettag',
    'update'			=> 'Asset update',
    'warranty'			=> 'Garantie',
        'warranty_expires'		=> 'Garantie vervalt',
    'years'				=> 'jaar',
    'asset_location' => 'Update Asset locatie',
    'asset_location_update_default_current' => 'Update standaard locatie EN huidige locatie',
    'asset_location_update_default' => 'Update alleen standaard locatie',
    'asset_not_deployable' => 'Deze Asset status is niet uitgeefbaar. Dit Asset kan niet uitgegeven worden.',
    'asset_deployable' => 'Deze status is uitgeefbaar. Dit Asset kan uitgegeven worden.',
    'processing_spinner' => 'Verwerken...',
];
